Installation
============

Install from GitHub
-------------------

Clone the repository and install the package::

    git clone https://github.com/AlexEngelhardt/startup-name-generator.git
    cd startup-name-generator
    python setup.py install

I think this also works::

    pip install --upgrade git+git://github.com/AlexEngelhardt/startup-name-generator.git



Install from PyPI
-----------------

Just issue::

    pip install sng

I am still working on making this package available on PyPI though.
